import middy from '@middy/core';
import { APIGatewayProxyEvent, APIGatewayProxyResult, Context, ScheduledEvent } from 'aws-lambda';
import { ObjectSchema } from 'joi';
/**
 * The AWS Lambda handler function signature for API Gateway proxy events.
 */
export type APIGatewayHandlerFn = (event: APIGatewayProxyEvent, context: Context) => Promise<APIGatewayProxyResult>;
/**
 * The AWS Lambda handler function signature for Scheduled events
 * (e.g. cron events from AWS EventBridge).
 */
export type ScheduledHandlerFn = (event: ScheduledEvent, context: Context) => Promise<void>;
/**
 * Base options for `middyfy` functions.
 */
export type MiddyfyOptions<THandler> = {
    handler: THandler;
    logger?: (message: string) => void;
};
/**
 * Options for middyfied API Gateway event handler functions.
 */
export type APIGatewayMiddyfyOptions = MiddyfyOptions<APIGatewayHandlerFn> & {
    eventSchema?: ObjectSchema;
    defaultErrorMessage?: string;
    defaultErrorStatusCode?: number;
};
/**
 * Options for middyfied Scheduled event handler functions.
 */
export type ScheduledMiddyfyOptions = MiddyfyOptions<ScheduledHandlerFn> & {
    eventSchema?: ObjectSchema;
};
/**
 * Wraps an AWS Gateway proxy event handler function in middleware, returning the
 * AWS Lambda handler function.
 * @param options - The `APIGatewayMiddyfyOptions` object.
 * @returns A middyfied handler function.
 */
export declare const middyfyAPIGateway: (options: APIGatewayMiddyfyOptions) => middy.MiddyfiedHandler<APIGatewayProxyEvent & Omit<APIGatewayProxyEvent, "body"> & {
    body: import("type-fest").JsonValue;
} & {
    multiValueQueryStringParameters: import("aws-lambda").APIGatewayProxyEventMultiValueQueryStringParameters;
    pathParameters: import("aws-lambda").APIGatewayProxyEventPathParameters;
    queryStringParameters: import("aws-lambda").APIGatewayProxyEventQueryStringParameters;
}, APIGatewayProxyResult, Error, Context>;
/**
 * Wraps a Scheduled event handler function in middleware, returning the
 * AWS Lambda handler function.
 * @param options - The `ScheduledMiddyfyOptions` object.
 * @returns A middyfied handler function.
 */
export declare const middyfyScheduled: (options: ScheduledMiddyfyOptions) => middy.MiddyfiedHandler<ScheduledEvent<any>, void, Error, Context>;
